# Convert CSV File to Parquet on IBM Cloud Object Storage

## Todos

### Objects:
- [x] Create connection
- [x] Create Convert object

### Methods:
- [x] list all objects in bucket
- [x] read csv files
- [x] convert to parquet

### User Stories
- [ ] allow users to input a single object
- [ ] allow users to input array of objects
